@@ -60,6 +60,13 @@ def read_hourly_file(fname):
 		# drop old index
 		df.drop(['date', 'hour'], axis=1, inplace=True)
 		df.columns = ['value', 'origin', 'tstamp']
+	elif fname.endswith('.csv'):
+		# read the file
+		df = pd.read_csv(fname)
+
+		# rename the columns
+		df.columns = [s.lower() for s in df.columns]
+		df.rename(columns={'th': 'value', 'date': 'tstamp'}, inplace=True)
 	else:
 		raise AttributeError('The file format is not yet supported.')
 	return df
@@ -80,7 +87,7 @@ class HydenvHoboImporter:
 		Session = sessionmaker(bind=self.engine)
 		self.session = Session()
 
-	def metadata(self, url: str, term: str = None, if_exists='append', quiet=True):
+	def metadata(self, url: str, term: str = None, if_exists='append', quiet=True, dry=False):
 		"""
 		Copy metadata from google tables.\n
 		Make sure that the URL format is correct. Open the correct sheet and copy the url,
@@ -109,7 +116,8 @@ class HydenvHoboImporter:
 		# remove anything without device id
 		df.rename({'hobo_id': 'device_id'}, axis=1, inplace=True)
 		df = df.where(~df.device_id.isnull()).dropna(how='all')
-		df['device_id'] = df.device_id.astype(int)
+		# df['device_id'] = df.device_id.astype(int)
+		df['device_id'] = ['%d' % int(_) for _ in df.device_id]
 
 		# convert lon lat
 		df = df.where(~df.longitude.isnull()).dropna(how='all')
@@ -143,6 +151,12 @@ class HydenvHoboImporter:
 		# add sensor info
 		df['sensor_id'] = hobo.id
 
+		if dry:
+			if not quiet:
+				return df.to_markdown()
+			else:
+				return df
+		
 		# upload
 		for d in df.to_dict('records'):
 			try:
